// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KCALENDARCORE_VERSION_H
#define KCALENDARCORE_VERSION_H

#define KCALENDARCORE_VERSION_STRING "6.23.0"
#define KCALENDARCORE_VERSION_MAJOR 6
#define KCALENDARCORE_VERSION_MINOR 23
#define KCALENDARCORE_VERSION_PATCH 0
#define KCALENDARCORE_VERSION ((6<<16)|(23<<8)|(0))

#endif
